@@ -88,12 +88,12 @@ def print_test():
     listaDadosBradesco = []
     for i in range(2):
         d = BoletoBradesco()
-        d.carteira = '57'  # Contrato firmado com o Banco Bradesco
+        d.carteira = '06'  # Contrato firmado com o Banco Bradesco
         d.cedente = 'Empresa Empresa Empresa Empresa Empresa LTDA'
-        d.agencia_cedente = '0531-3'
-        d.conta_cedente = '5705853-2'
+        d.agencia_cedente = '0278-0'
+        d.conta_cedente = '43905-3'
 
-        d.data_vencimento = datetime.date(2010, 3, 27)
+        d.data_vencimento = datetime.date(2011, 1, 25)
         d.data_documento = datetime.date(2010, 02, 12)
         d.data_processamento = datetime.date(2010, 02, 12)
 
@@ -106,10 +106,10 @@ def print_test():
             "- Serviço Teste R$ 5,00",
             "- Total R$ 5,00",
             ]
-        d.valor_documento = 5.00
+        d.valor_documento = 2158.41
 
-        d.nosso_numero = "%d" % (i+2)
-        d.numero_documento = "%d" % (i+2)
+        d.nosso_numero = "1112011668"
+        d.numero_documento = "1112011668"
         d.sacado = [
             "Cliente Teste %d" % (i+1),
             "Rua Desconhecida, 00/0000 - Não Sei - Cidade - Cep. 00000-000",
